require 'spec_helper'

describe Project do

  before(:each) do
    @project =  Project.create!(name: 'delinquo')
  end
  
  after(:each) do
    Project.delete_all
  end

  it "is not valid without a project name" do
    project = Project.new
    project.name = nil
    project.should_not be_valid
  end

  it "is not valid if the name is not unique" do
    Project.create!(name: 'cookie').should be_valid
    project = Project.new(name: 'cookie')
    project.should_not be_valid
  end

  describe ".failing_runs" do
    it "should return the number of failing runs" do
      @project.runs.create(total: '500')
      add_runs 3, 'failing'
      @project.failing_runs.should == 3
    end
  end

  describe ".top_fail" do
    it "should return the projects most common failing test" do
      add_runs 1, 'failing'
      @project.runs.create(total: '500').fails.create! feature: 'a feature', scenario: 'a scenario', step: 'a step', line: 'this is the most fequently failing test'
      @project.runs.create(total: '500').fails.create! feature: 'a feature', scenario: 'a scenario', step: 'a step', line: 'this is the most fequently failing test'
      @project.runs.create(total: '500').fails.create! feature: 'a feature', scenario: 'a scenario', step: 'a step', line: 'this is the most fequently failing test'
      @project.top_fail.should == 'this is the most fequently failing test'
    end
  end

  describe ".forcast" do
    context "should return the current state of the build as a weather forcast" do

      it "returns sun, when the number of failing runs is 0" do
        @project.runs.create(total: '500')
        @project.forecast.should == "sun"
      end

      it "returns changeable, when the number of failinng runs is between 1 and 3" do
        add_runs 3, 'failing'
        @project.forecast.should == "changeable"
      end

      it "returns cloud, when the number of failing runs is between 4 and 6" do
        add_runs 6, 'failing'
        @project.forecast.should == "cloud"
      end

      it "returns rain, when the number of failing runs is between 7 and 9" do
        add_runs 9, 'failing'
        @project.forecast.should == "rain"
      end

      it "returns storm, when the number of failing runs is 10" do
        add_runs 10, 'failing'
        @project.forecast.should == "storm"
      end

    end
  end

end