require 'spec_helper'

describe Run do
  
  before(:each) do
     @run = Run.create!(total: '100')
  end

  after(:each ) do
    Run.delete_all
  end
  
  it "should return the total number of tests" do
    @run.total_number_of_tests.should == 100
  end

  it "should return the total number of failed tests" do
    add_fails 3
    @run.total_failed.should == 3
  end

  it "should return the total number of passes" do
    @run.total = 100
    add_fails 3
    @run.total_passed.should == 97
  end

  it "should return the percentage of fails" do
    @run.total = 100
    add_fail

    @run.percentage_failed.should == 1
  end

  it "should return the percentage fails rounded up to a whole number" do
    @run.total = 200
    add_fails 25

    @run.percentage_failed.should == 13
  end

  it "should return 0%, if total number of tests is 0" do
     @run.total = 0
     @run.percentage_failed.should == 0
  end

  it "should return the percentage of passes" do
    @run.total = 100
    add_fail
    @run.percentage_passed.should == 99
  end

  it "should return 100% passed when there are no tests" do
    @run.total = 0
    @run.percentage_passed.should == 100
  end

  it "should return a formatted date and time" do
    @run.created_at ='2013-10-02 07:34:49'
    @run.date_time.should == "02/10/2013 07.34"
  end

  it "should return all the fail lines in a run" do
    fails = [
        Fail.new(feature: 'a feature', scenario: 'a scenario', step: 'a step', line: 'a line 1'),
        Fail.new(feature: 'a feature', scenario: 'a scenario', step: 'a step', line: 'a line 2')
      ]
      @run.fails = fails
      @run.unique_failing_lines.should == ['a line 1', 'a line 2']
  end

end

def add_fails(number=1)
  number.times do
    @run.fails.create! feature: 'a feature', scenario: 'a scenario', step: 'a step', line: 'a line'
  end
end

def add_fail
  @run.fails.create! feature: 'a feature', scenario: 'a scenario', step: 'a step', line: 'a line'
end
